// src/components/ItemDetails.js
import React, { useState } from 'react';
import { TextField, Button, Container } from '@mui/material';
import axios from 'axios';

export default function ItemDetails({ item, token, onSave }) {
  const [name, setName] = useState(item.name);
  const [description, setDescription] = useState(item.description);
  const [imagePath, setImagePath] = useState(item.image_path || '');

  const handleSave = () => {
    axios.put(`${process.env.REACT_APP_API_URL}/items/${item.ID}`, 
      { name, description, image_path: imagePath },
      {
        headers: { Authorization: `Bearer ${token}` }
      }
    ).then(() => {
      onSave(); // Notify parent to refresh items
    });
  };

  return (
    <Container>
      <h3>Edit Item: {item.name}</h3>
      <TextField
        label="Item Name"
        variant="outlined"
        fullWidth
        margin="normal"
        value={name}
        onChange={(e) => setName(e.target.value)}
      />
      <TextField
        label="Item Description"
        variant="outlined"
        fullWidth
        margin="normal"
        value={description}
        onChange={(e) => setDescription(e.target.value)}
      />
      <TextField 
        label="Item Image Path" 
        variant="outlined" 
        fullWidth 
        margin="normal"
        value={imagePath}
        onChange={(e) => setImagePath(e.target.value)} 
      />
      <Button variant="contained" color="primary" onClick={handleSave}>
        Save Changes
      </Button>
    </Container>
  );
}